==> sd-shared-web-favorite-postgres-1.0.4-sources.jar: systems/dennis/shared/favorite/controller/FavoriteItemController.java <==
package systems.dennis.shared.favorite.controller;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import systems.dennis.shared.annotations.DataRetrieverDescription;
import systems.dennis.shared.annotations.WebFormsSupport;
import systems.dennis.shared.annotations.security.Secured;
import systems.dennis.shared.annotations.security.WithRole;
import systems.dennis.shared.config.WebContext;
import systems.dennis.shared.controller.SearchEntityApi;
import systems.dennis.shared.postgres.model.BaseEntity;
import systems.dennis.shared.exceptions.ItemNotFoundException;
import systems.dennis.shared.exceptions.ItemNotUserException;
import systems.dennis.shared.favorite.exception.FavoriteException;
import systems.dennis.shared.favorite.form.FavoriteItemForm;
import systems.dennis.shared.favorite.model.FavoriteItemModel;
import systems.dennis.shared.favorite.service.FavoriteItemService;
import systems.dennis.shared.postgres.controller.AddItemController;
import systems.dennis.shared.postgres.controller.DeleteItemController;
import systems.dennis.shared.repository.AbstractDataFilter;
import systems.dennis.shared.utils.ApplicationContext;
import systems.dennis.shared.utils.bean_copier.BeanCopier;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import static systems.dennis.shared.form.AbstractForm.ID_FIELD;

@RestController
@RequestMapping("/api/v2/shared/favorite")
@WebFormsSupport(value = FavoriteItemService.class)
@CrossOrigin
@Secured
public class FavoriteItemController<ID_TYPE extends Serializable> extends ApplicationContext
        implements AddItemController<FavoriteItemModel, FavoriteItemForm>,
        DeleteItemController<FavoriteItemModel> {

    public FavoriteItemController(WebContext context) {
        super(context);
    }

    @GetMapping("/enabled")
    @ResponseBody
    @WithRole
    public ResponseEntity<FavoriteResponse> enabled() {

        return ResponseEntity.ok(new FavoriteResponse(getService().getIsFavoriteEnabled(), ""));
    }


    @GetMapping("/byName")
    @ResponseBody
    @WithRole
    public ResponseEntity<FavoriteResponse> byName(@RequestParam("name") String name) {

        return ResponseEntity.ok(new FavoriteResponse(getService().getIsFavoriteEnabled(), getService().findBySearchName(name)));
    }


    @PostMapping("/is_favorite")
    @ResponseBody
    @WithRole
    public ResponseEntity<FavoriteResponse> isFavorite(@RequestBody FavoriteItemForm form) {
        return ResponseEntity.ok(new FavoriteResponse(getService().isFavoriteForObject(form), ""));
    }


    @PostMapping("/delete")

    public FavoriteResponse delete(@RequestBody FavoriteItemForm id) throws ItemNotUserException, ItemNotFoundException {
        getService().delete(id);
        return  new FavoriteResponse(true, "");
    }

    @GetMapping("/list/{type}/{searchName}")
    @ResponseBody
    @WithRole
    public ResponseEntity<Page<Map<String, Object>>> findByType(@PathVariable String type, @PathVariable("searchName") String name,
                                                             @RequestParam(value = "limit", required = false) Integer limit,
                                                             @RequestParam(value = "page", required = false) Integer page) {

        if (!getService().getIsFavoriteEnabled()){
            return ResponseEntity.ok(Page.empty());
        }

        var searchBean = SearchEntityApi.findServiceByType(name);

        if (searchBean == null){
            throw new FavoriteException("global.exception.favorite.no_search_type_present");
        }

        AbstractDataFilter<FavoriteItemModel> specification = getService().getFilterImpl().eq("userDataId", getContext().getCurrentUser())
                .and(getService().getFilterImpl().eq("type", type));
        Page<FavoriteItemModel> models = getContext().getBean(FavoriteItemService.class).find(specification, limit, page);

        List<Long> ids = models.stream().map(FavoriteItemModel::getModelId).collect(Collectors.toList());

        var bean = getContext().getBean(searchBean);



        return ResponseEntity.ok(toFormPage(bean.find(getService().getFilterImpl().iN(ID_FIELD, ids),-1, 0), searchBean));
    }


    public Page<Map<String, Object>> toFormPage(Page<?extends BaseEntity> page, Class<?> c) {
        var ann = c.getAnnotation(DataRetrieverDescription.class);
        var copier = getBean(BeanCopier.class);
        List<Map<String, Object>> data = new ArrayList<>();
        for (BaseEntity entity : page.getContent()){

            data.add(BeanCopier.values(copier.copy(entity, ann.form()), entity, getContext()));
        }

        return new PageImpl<>(data, page.getPageable(), data.size());
    }

    @Override
    public FavoriteItemService getService() {
        return  AddItemController.super.getService();
    }
}

==> sd-shared-web-favorite-postgres-1.0.5-sources.jar: systems/dennis/shared/favorite/controller/FavoriteItemController.java <==
package systems.dennis.shared.favorite.controller;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import systems.dennis.shared.annotations.DataRetrieverDescription;
import systems.dennis.shared.annotations.WebFormsSupport;
import systems.dennis.shared.annotations.security.Secured;
import systems.dennis.shared.annotations.security.WithRole;
import systems.dennis.shared.config.WebContext;
import systems.dennis.shared.controller.SearchEntityApi;
import systems.dennis.shared.postgres.controller.ListItemController;
import systems.dennis.shared.postgres.controller.SelfItemsListController;
import systems.dennis.shared.postgres.model.BaseEntity;
import systems.dennis.shared.exceptions.ItemNotFoundException;
import systems.dennis.shared.exceptions.ItemNotUserException;
import systems.dennis.shared.favorite.exception.FavoriteException;
import systems.dennis.shared.favorite.form.FavoriteItemForm;
import systems.dennis.shared.favorite.model.FavoriteItemModel;
import systems.dennis.shared.favorite.service.FavoriteItemService;
import systems.dennis.shared.postgres.controller.AddItemController;
import systems.dennis.shared.postgres.controller.DeleteItemController;
import systems.dennis.shared.repository.AbstractDataFilter;
import systems.dennis.shared.utils.ApplicationContext;
import systems.dennis.shared.utils.bean_copier.BeanCopier;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import static systems.dennis.shared.form.AbstractForm.ID_FIELD;

@RestController
@RequestMapping("/api/v2/shared/favorite")
@WebFormsSupport(value = FavoriteItemService.class)
@CrossOrigin
@Secured
public class FavoriteItemController<ID_TYPE extends Serializable> extends ApplicationContext
        implements AddItemController<FavoriteItemModel, FavoriteItemForm>, ListItemController<FavoriteItemModel, FavoriteItemForm>,
        DeleteItemController<FavoriteItemModel> {

    public FavoriteItemController(WebContext context) {
        super(context);
    }

    @GetMapping("/enabled")
    @ResponseBody
    @WithRole
    public ResponseEntity<FavoriteResponse> enabled() {

        return ResponseEntity.ok(new FavoriteResponse(getService().getIsFavoriteEnabled(), ""));
    }


    @GetMapping("/byName")
    @ResponseBody
    @WithRole
    public ResponseEntity<FavoriteResponse> byName(@RequestParam("name") String name) {

        return ResponseEntity.ok(new FavoriteResponse(getService().getIsFavoriteEnabled(), getService().findBySearchName(name)));
    }


    @PostMapping("/is_favorite")
    @ResponseBody
    @WithRole
    public ResponseEntity<FavoriteResponse> isFavorite(@RequestBody FavoriteItemForm form) {
        return ResponseEntity.ok(new FavoriteResponse(getService().isFavoriteForObject(form), ""));
    }


    @PostMapping("/delete")

    public FavoriteResponse delete(@RequestBody FavoriteItemForm id) throws ItemNotUserException, ItemNotFoundException {
        getService().delete(id);
        return  new FavoriteResponse(true, "");
    }

    @GetMapping("/list/{type}/{searchName}")
    @ResponseBody
    @WithRole
    public ResponseEntity<Page<Map<String, Object>>> findByType(@PathVariable String type, @PathVariable("searchName") String name,
                                                             @RequestParam(value = "limit", required = false) Integer limit,
                                                             @RequestParam(value = "page", required = false) Integer page) {

        if (!getService().getIsFavoriteEnabled()){
            return ResponseEntity.ok(Page.empty());
        }

        var searchBean = SearchEntityApi.findServiceByType(name);

        if (searchBean == null){
            throw new FavoriteException("global.exception.favorite.no_search_type_present");
        }

        AbstractDataFilter<FavoriteItemModel> specification = getService().getFilterImpl().eq("userDataId", getContext().getCurrentUser())
                .and(getService().getFilterImpl().eq("type", type));
        Page<FavoriteItemModel> models = getContext().getBean(FavoriteItemService.class).find(specification, limit, page);

        List<Long> ids = models.stream().map(FavoriteItemModel::getModelId).collect(Collectors.toList());

        var bean = getContext().getBean(searchBean);



        return ResponseEntity.ok(toFormPage(bean.find(getService().getFilterImpl().iN(ID_FIELD, ids),-1, 0), searchBean));
    }


    public Page<Map<String, Object>> toFormPage(Page<?extends BaseEntity> page, Class<?> c) {
        var ann = c.getAnnotation(DataRetrieverDescription.class);
        var copier = getBean(BeanCopier.class);
        List<Map<String, Object>> data = new ArrayList<>();
        for (BaseEntity entity : page.getContent()){

            data.add(BeanCopier.values(copier.copy(entity, ann.form()), entity, getContext()));
        }

        return new PageImpl<>(data, page.getPageable(), data.size());
    }

    @Override
    public FavoriteItemService getService() {
        return (FavoriteItemService) getBean(getServiceClass());
    }
}
